@@ -53,8 +53,11 @@ class Cluster:
                 pretty_print.print_no_resources_found()
             return None
     
-    def cluster_uri(self):        
-        return f'ray://{self.config.name}-head-svc:1001'
+    def cluster_uri(self, namespace='default'):
+        return f'ray://{self.config.name}-head-svc.{namespace}.svc:10001'
+
+    def cluster_dashboard_uri(self, namespace='default'):
+        return f'http://{self.config.name}-head-svc.{namespace}.svc:8265'
 
 
     # checks whether the ray cluster is ready
@@ -74,6 +77,8 @@ class Cluster:
             elif appwrapper.status in [AppWrapperStatus.PENDING]:
                 ready = False
                 status = CodeFlareClusterStatus.QUEUED 
+                if print_to_console:
+                    pretty_print.print_app_wrappers_status([appwrapper])
                 return ready, status# no need to check the ray status since still in queue
 
         # check the ray cluster status
@@ -101,7 +106,7 @@ def list_all_clusters(print_to_console=True):
 def list_all_queued(print_to_console=True):
     app_wrappers = _get_app_wrappers(filter=[AppWrapperStatus.RUNNING, AppWrapperStatus.PENDING])
     if print_to_console:
-        pretty_print.print_appwrappers_status(app_wrappers)
+        pretty_print.print_app_wrappers_status(app_wrappers)
     return app_wrappers
    
 
