@@ -12,8 +12,8 @@ def print_no_resources_found():
     console.print(Panel("[red]No resources found"))
 
 
-def print_appwrappers_status(app_wrappers:List[AppWrapper]):
-    if not app_wrappers == 0:
+def print_app_wrappers_status(app_wrappers:List[AppWrapper]):
+    if not app_wrappers:
         print_no_resources_found()
         return #shortcircuit
     
